import { r as registerInstance, c as createEvent, h, g as getElement } from './p-597600b0.js';
import { j as getElementKey, k as updateConfigData, g as getControlSection, l as loadAndUpdatePageConfig, u as updateCurrentTabWithMappingsFromOtherTabs, c as updateResultants, d as getOutputSubCategoriesObj, e as updateSelectedOutputSubCategoryId, f as getOutputSection, h as getTabNamesObj, i as updateSelectedTabId } from './p-31525cd2.js';
import './p-3ab399ac.js';

const adsTueCss = ":root{font-family:Roboto}.d-none{display:none}.v-hidden{visibility:hidden}.c-pointer{cursor:pointer}.disabled{cursor:not-allowed;opacity:0.6}.fw-bold{font-weight:bold}::-webkit-scrollbar-track{background-color:var(--color-ti-bg-grey);border-radius:5px}::-webkit-scrollbar{background-color:var(--color-ti-bg-grey);height:5px;width:5px}::-webkit-scrollbar-thumb{background-color:var(--color-ti-text-grey);border-radius:5px}ads-popup::part(popup-container){height:75%;width:75%}.page-header{box-sizing:content-box;display:flex;height:28px;justify-content:space-between;padding-bottom:5px}.page-header .page-title{color:var(--color-ti-text-grey);font-size:24px}.page-content{display:flex;height:calc(100% - 33px)}.page-content .left-section,.page-content .right-section{display:flex;flex-direction:column;gap:2%;height:100%;min-height:670px;padding:2%}.page-content .left-section{background-color:var(--color-ti-primary-white);min-width:540px;width:40%}.page-content .right-section{background-color:#f2f8fa;min-width:720px;width:60%}.popup-btn{align-items:center;cursor:pointer;display:flex;text-decoration:underline}.popup-content{display:flex;flex-direction:column}.popup-content img{margin:auto;max-height:calc(100% - 100px);max-width:calc(100% - 100px)}.popup-content .title{background-color:var(--color-ti-indicator-grey);font-size:1.5rem;font-weight:bold;height:40px;margin:0 auto;padding:5px;text-align:center;width:50%}.section-title{color:var(--color-ti-text-blue);font-size:18px}.section-tabs,.section-outputs{display:flex;flex-direction:column;height:100%;overflow:auto;width:100%}.section-outputs ads-tabs{--selected-tab-color:var(--color-ti-primary-blue-dark)}.section-outputs .tab-content{display:flex;flex-direction:column}.tab-content{height:max-content;overflow:hidden auto;width:100%}.tab-content ads-control{--control-label-width:50%}.tab-content .group-title{color:var(--color-ti-primary-red);font-size:1.2em;margin-top:5%}*{box-sizing:border-box}:host{background-color:var(--color-ti-bg-grey-dark);display:flex;flex-direction:column;height:100%;overflow:auto;padding:2%;width:100%}:host .left-section{min-height:0px;min-width:600px;gap:0%;padding:1%}:host .max-height{height:100%}:host .right-section{min-height:0px}:host .single-line{display:flex;gap:20px;position:relative}:host .extend-width{width:50%}:host .no-margin-top{margin-top:0}:host .fixed-margin-top{margin-top:40px !important}:host .reduce-margin{margin:1% 5%}:host .export-button{color:white;font-weight:bold;font-size:14px;background-color:var(--color-ti-text-blue);border:0px solid;width:100px;margin-right:5px;margin-left:auto;cursor:pointer}:host .export-button:hover{background-color:var(--color-ti-secondary-blue-light)}:host .button-label{position:relative;bottom:5px;padding-right:10px}:host .export-button:active{box-shadow:0px 0px 5px 1px var(--color-ti-text-blue)}gc-widget-dialog{--gc-modal-opacity:0.8;z-index:-1}gc-widget-dialog .dialog-content{width:310px;padding:20px}";

const AdsCodeConversion = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    this.showToast = createEvent(this, "showToast", 7);
    // ---------- Internal variables ----------
    this.computationAPIs = {};
    this.isComputedValuesInitialized = false;
    this.isInitializationApisDeleted = false;
    // ----------- Helper methods -------------
    this.getClassNames = (className, label = "") => {
      let classNames = "";
      if (className) {
        classNames += className === "group-control-one" ? "extend-width " : "";
        classNames += label !== "" ? "fixed-margin-top " : "";
        classNames += className.includes("group-control") ? "no-margin-top" : "";
      }
      return classNames;
    };
    /**
     * To get control element
     * @param controlInfo
     * @param dataPath
     * @returns control element
     */
    this.getControlElement = (controlInfo, dataPath) => {
      return (h("ads-control", { class: this.getClassNames(controlInfo.class, controlInfo.topLabel ? controlInfo.topLabel : ""), key: getElementKey(controlInfo), controlInfo: controlInfo, dataPath: dataPath, onSetPathValue: ev => {
          if (this.isComputedValuesInitialized &&
            !this.isInitializationApisDeleted) {
            for (const api in this.computationAPIs) {
              if (api.startsWith("initialize")) {
                delete this.computationAPIs[api];
              }
            }
            this.isInitializationApisDeleted = true;
          }
          updateConfigData.call(this, ev);
        } }));
    };
    /**
     * To get control groups
     * @returns Control groups
     */
    this.getControlSectionGroups = () => {
      const groupsInfo = getControlSection.call(this);
      let groups = [];
      groupsInfo.forEach(group => {
        groups.push(h("div", null, group.title ? h("div", { class: "group-title" }, group.title) : null, h("div", { class: group.class ? group.class : "" }, ...group.controls)));
      });
      return groups;
    };
    /**
     * To get output info
     * @param outputInfo Output info object
     * @returns Output element
     */
    this.getOutputElement = (outputInfo, dataPath) => {
      return (h("ads-output", { class: outputInfo.class && outputInfo.class === "group-output"
          ? "reduce-margin"
          : "", "selected-device": this.selectedDevice, "tool-name": "code-conversion", key: getElementKey(outputInfo), outputInfo: outputInfo, dataPath: dataPath, onSetPathValue: ev => {
          if (this.isComputedValuesInitialized &&
            !this.isInitializationApisDeleted) {
            for (const api in this.computationAPIs) {
              if (api.startsWith("initialize")) {
                delete this.computationAPIs[api];
              }
            }
            this.isInitializationApisDeleted = true;
          }
          updateConfigData.call(this, ev);
        } }));
    };
    this._resetDefaults = (e) => {
      this.isComputedValuesInitialized = false;
      this.isInitializationApisDeleted = false;
      this.config = undefined;
      this.loadPageConfig();
      this.closeResetConfirmationPopup();
      let today = new Date();
      let time = today.getHours().toString().padStart(2) +
        "-" +
        today.getMinutes().toString().padStart(2) +
        "-" +
        today.getSeconds().toString().padStart(2);
      `${this.showToast.emit({
        message: `Reset Tue ${time}`,
      })}`;
    };
    this.showResetConfirmationPopup = () => {
      this.dialog.open();
    };
    this.closeResetConfirmationPopup = () => {
      this.dialog.close();
    };
    this.selectedDevice = undefined;
    this.selectedPageIndex = undefined;
    this.selectedToolName = undefined;
    this.config = undefined;
    this.selectedTabId = undefined;
    this.selectedOutputSubCategoryId = undefined;
  }
  // ---------- Life cycle methods ----------
  componentDidLoad() {
    if (this.config === undefined && this.selectedDevice !== undefined) {
      this.loadPageConfig();
    }
  }
  // ----------- Watch handlers -------------
  loadPageConfig() {
    loadAndUpdatePageConfig.call(this, this.selectedToolName, this.selectedDevice);
  }
  onSelectedTabChanged() {
    if (this.config != undefined) {
      updateCurrentTabWithMappingsFromOtherTabs.call(this);
      updateResultants.call(this, true);
    }
  }
  render() {
    return this.config != undefined && this.isComputedValuesInitialized
      ? [
        h("div", { class: "page-header" }, h("div", { class: "page-title" }, "Total Unadjusted Error (TUE) Tool"), h("button", { class: "export-button", onClick: this.showResetConfirmationPopup }, h("svg", { id: "restore-factory-defaults", width: "25px", height: "22px", viewBox: "0 0 20 14", version: "1.1", xmlns: "http://www.w3.org/2000/svg" }, h("g", { id: "Icons", stroke: "none", "stroke-width": "1", fill: "none", "fill-rule": "evenodd" }, h("g", { transform: "translate(-827.000000, -60.000000)", id: "RESTORE-DEFAULTS" }, h("g", { transform: "translate(827.000000, 60.000000)" }, h("rect", { id: "Rectangle-Copy-19", x: "0", y: "0", width: "16", height: "16" }), h("g", { id: "RESTORE-DEFAULTS_GRAY" }, h("rect", { id: "Rectangle-Copy-26", x: "0", y: "0", width: "16", height: "16" }), h("path", { d: "M11.5303315,4.46875 C10.6235147,3.5625 9.37898687,3 7.99687305,3 C5.2326454,3 3,5.2375 3,8 C3,10.7625 5.2326454,13 7.99687305,13 C10.329581,13 12.2745466,11.40625 12.8311445,9.25 L11.5303315,9.25 C11.0175109,10.70625 9.62914321,11.75 7.99687305,11.75 C5.92682927,11.75 4.24452783,10.06875 4.24452783,8 C4.24452783,5.93125 5.92682927,4.25 7.99687305,4.25 C9.03502189,4.25 9.96060038,4.68125 10.6360225,5.3625 L8.62226391,7.375 L13,7.375 L13,3 L11.5303315,4.46875 Z", id: "Path-Copy-4", fill: "#ffffff", "fill-rule": "nonzero" })))))), h("span", { class: "button-label" }, "Reset")), h("ads-dropdown-menu", { name: "Related links", items: this.config.collaterals })),
        h("div", { class: "page-content" }, h("div", { class: "left-section", id: "left-section" }, h("div", { class: "section-title" }, this.config.label), h("div", { class: "section-tabs" }, h("ads-tabs", { tabNamesObj: getTabNamesObj(this.config.tabs), selectedTabId: this.selectedTabId, selectedPageIndex: this.selectedPageIndex, onUpdateSelectedTab: ev => updateSelectedTabId.call(this, ev), "hide-if-single-tab": true }), h("div", { class: "tab-content max-height" }, this.getControlSectionGroups()))), h("div", { class: "right-section", id: "right-section" }, h("div", { class: "section-title" }, "Resultant Calculations"), h("div", { class: "section-outputs" }, this.selectedTabId != undefined && (h("ads-tabs", { tabNamesObj: getOutputSubCategoriesObj.call(this), selectedTabId: this.selectedOutputSubCategoryId, selectedPageIndex: this.selectedPageIndex, onUpdateSelectedTab: ev => updateSelectedOutputSubCategoryId.call(this, ev), "hide-if-single-tab": true })), h("div", { class: "tab-content" }, getOutputSection.call(this))))),
        h("gc-widget-dialog", { modal: true, ref: (el) => (this.dialog = el), heading: "Reset Default", closeOnEsc: true, resizable: false }, h("div", { class: "dialog-content" }, "This will reset all the controls to their default values. Do you want to continue?"), h("gc-widget-button", { slot: "action-bar", label: "No", "button-type": "link", onClick: this.closeResetConfirmationPopup }), h("gc-widget-button", { slot: "action-bar", label: "Yes", "button-type": "link", onClick: this._resetDefaults })),
      ]
      : [];
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "selectedDevice": ["loadPageConfig"],
    "selectedTabId": ["onSelectedTabChanged"]
  }; }
};
AdsCodeConversion.style = adsTueCss;

export { AdsCodeConversion as ads_tue };

//# sourceMappingURL=p-35c5d1cf.entry.js.map