import { r as registerInstance, h, g as getElement } from './p-597600b0.js';
import { g as getControlSection, a as getGraphLayoutObj, b as getGraphDataObj, l as loadAndUpdatePageConfig, u as updateCurrentTabWithMappingsFromOtherTabs, c as updateResultants, d as getOutputSubCategoriesObj, e as updateSelectedOutputSubCategoryId, f as getOutputSection, h as getTabNamesObj, i as updateSelectedTabId, j as getElementKey, k as updateConfigData } from './p-31525cd2.js';
import { H as HTML_ENTITIES, C as COLORS, c as configImageDirPath, I as ICONS } from './p-3ab399ac.js';

const adsCmRangeCss = ":root{font-family:Roboto}.d-none{display:none}.v-hidden{visibility:hidden}.c-pointer{cursor:pointer}.disabled{cursor:not-allowed;opacity:0.6}.fw-bold{font-weight:bold}::-webkit-scrollbar-track{background-color:var(--color-ti-bg-grey);border-radius:5px}::-webkit-scrollbar{background-color:var(--color-ti-bg-grey);height:5px;width:5px}::-webkit-scrollbar-thumb{background-color:var(--color-ti-text-grey);border-radius:5px}ads-popup::part(popup-container){height:75%;width:75%}.page-header{box-sizing:content-box;display:flex;height:28px;justify-content:space-between;padding-bottom:5px}.page-header .page-title{color:var(--color-ti-text-grey);font-size:24px}.page-content{display:flex;height:calc(100% - 33px)}.page-content .left-section,.page-content .right-section{display:flex;flex-direction:column;gap:2%;height:100%;min-height:670px;padding:2%}.page-content .left-section{background-color:var(--color-ti-primary-white);min-width:540px;width:40%}.page-content .right-section{background-color:#f2f8fa;min-width:720px;width:60%}.popup-btn{align-items:center;cursor:pointer;display:flex;text-decoration:underline}.popup-content{display:flex;flex-direction:column}.popup-content img{margin:auto;max-height:calc(100% - 100px);max-width:calc(100% - 100px)}.popup-content .title{background-color:var(--color-ti-indicator-grey);font-size:1.5rem;font-weight:bold;height:40px;margin:0 auto;padding:5px;text-align:center;width:50%}.section-title{color:var(--color-ti-text-blue);font-size:18px}.section-tabs,.section-outputs{display:flex;flex-direction:column;height:100%;overflow:auto;width:100%}.section-outputs ads-tabs{--selected-tab-color:var(--color-ti-primary-blue-dark)}.section-outputs .tab-content{display:flex;flex-direction:column}.tab-content{height:max-content;overflow:hidden auto;width:100%}.tab-content ads-control{--control-label-width:50%}.tab-content .group-title{color:var(--color-ti-primary-red);font-size:1.2em;margin-top:5%}*{box-sizing:border-box}:host{background-color:var(--color-ti-bg-grey-dark);display:flex;flex-direction:column;height:100%;overflow:auto;padding:2%;width:100%}:host ads-output{height:100%;margin:unset}";

const AdsCmRange = class {
  constructor(hostRef) {
    registerInstance(this, hostRef);
    // ---------- Internal variables ----------
    this.computationAPIs = {};
    this.isComputedValuesInitialized = false;
    // ----------- Helper methods -------------
    /**
     * To get control element
     * @param controlInfo
     * @param dataPath
     * @returns control element
     */
    this.getControlElement = (controlInfo, dataPath) => {
      return (h("ads-control", { key: getElementKey(controlInfo), controlInfo: controlInfo, dataPath: dataPath, onSetPathValue: ev => updateConfigData.call(this, ev) }));
    };
    /**
     * To get control groups
     * @returns Control groups
     */
    this.getControlSectionGroups = () => {
      const groupsInfo = getControlSection.call(this);
      let groups = [];
      groupsInfo.forEach(group => {
        groups.push(h("div", null, group.title ? h("div", { class: "group-title" }, group.title) : null, ...group.controls));
      });
      return groups;
    };
    /**
     * To get graph annotations info list
     * @param maxYValue
     * @param metaData
     * @returns Graph annotations info list
     */
    this.getGraphAnnotationsInfoList = (maxYValue, metaData) => {
      let errorAnnotations = [];
      if (metaData.error_voutp.status) {
        errorAnnotations.push({
          text: HTML_ENTITIES.leftArrow,
          fontColor: COLORS.red,
          x: 1.7,
          y: metaData.voutp_clamped,
          xanchor: "left",
        });
      }
      if (metaData.error_voutn.status) {
        errorAnnotations.push({
          text: HTML_ENTITIES.leftArrow,
          fontColor: COLORS.red,
          x: 1.7,
          y: metaData.voutn_clamped,
          xanchor: "left",
        });
      }
      if (metaData.error_vout_diff_exceeds_fsr.status ||
        metaData.error_voutp.status ||
        metaData.error_voutn.status) {
        errorAnnotations.push({
          fontColor: COLORS.red,
          text: "* Hover over the warning icon to know more about the error",
          x: 0,
          xanchor: "left",
          y: 0,
          yanchor: "top",
          otherOptions: {
            showarrow: false,
            xref: "paper",
            yref: "paper",
          },
        });
      }
      return [
        ...errorAnnotations,
        // + I/P to O/P Arrow
        {
          text: HTML_ENTITIES.rightArrow,
          x: 1.39,
          y: metaData.voutp_clamped,
        },
        // - I/P to O/P Arrow
        {
          text: HTML_ENTITIES.rightArrow,
          x: 1.39,
          y: metaData.voutn_clamped,
        },
        {
          text: "PGA Input",
          x: 0.5,
          y: maxYValue + 0.5,
          yanchor: "bottom",
        },
        {
          text: "PGA Output",
          x: 1.5,
          y: maxYValue + 0.5,
          yanchor: "bottom",
        },
        {
          text: "V<sub>AINP</sub>",
          x: 0.5,
          y: metaData.ainp,
          yanchor: "bottom",
          fontColor: COLORS.darkBlue,
        },
        {
          text: "V<sub>AINN</sub>",
          x: 0.5,
          y: metaData.ainn,
          yanchor: "top",
          fontColor: COLORS.maximumBlue,
        },
        {
          text: "V<sub>OUTP</sub>",
          x: 1.5,
          y: metaData.voutp_clamped,
          yanchor: "bottom",
          fontColor: COLORS.darkBlue,
        },
        {
          text: "V<sub>OUTN</sub>",
          x: 1.5,
          y: metaData.voutn_clamped,
          yanchor: "top",
          fontColor: COLORS.maximumBlue,
        },
        {
          text: "AVDD",
          x: 1.8,
          y: metaData.avdd,
          xanchor: "left",
        },
        {
          text: "AVSS",
          x: 1.8,
          y: metaData.avss,
          xanchor: "left",
        },
      ];
    };
    /**
     * To get graph image info
     * @param graphImage
     * @param metaData
     * @returns Graph image info
     */
    this.getGraphImageInfo = (graphImage, metaData) => {
      return {
        source: configImageDirPath + graphImage,
        x: 1,
        y: (metaData.avdd - metaData.avss) / 2 + metaData.avss,
        sizex: 1.5,
        sizey: 1.5,
      };
    };
    /**
     * To get graph line info list
     * @param metaData
     * @returns Graph line info list
     */
    this.getGraphLineInfoList = metaData => {
      const errorLineHoverLabel = {
        align: "left",
        bgcolor: COLORS.white,
        bordercolor: COLORS.red,
        font: {
          color: COLORS.red,
        },
      };
      let errorLines = [];
      if (metaData.error_vout_diff_exceeds_fsr.status) {
        errorLines.push(
        // VREF+
        {
          x: [1.7, 1.9],
          y: [metaData.vref_positive_limit, metaData.vref_positive_limit],
          color: COLORS.red,
        }, 
        // VREF-
        {
          x: [1.7, 1.9],
          y: [metaData.vref_negative_limit, metaData.vref_negative_limit],
          color: COLORS.red,
        }, 
        // VREF DIFF
        {
          x: [1.8, 1.8],
          y: [metaData.vref_positive_limit, metaData.vref_negative_limit],
          color: COLORS.red,
          dash: "dot",
        }, 
        // Warning Icon
        {
          otherOptions: {
            hoverlabel: errorLineHoverLabel,
            hovertemplate: `<b>${metaData.error_vout_diff_exceeds_fsr.text}</b><extra></extra>`,
            mode: "text",
            text: [ICONS.warningIcon],
            textfont: {
              color: COLORS.red,
              size: 25,
            },
          },
          x: [2],
          y: [
            (metaData.vref_positive_limit - metaData.vref_negative_limit) / 2 +
              metaData.vref_negative_limit,
          ],
        });
      }
      if (metaData.error_voutp.status) {
        errorLines.push({
          otherOptions: {
            hoverlabel: errorLineHoverLabel,
            hovertemplate: `<b>${metaData.error_voutp.text}</b><extra></extra>`,
            mode: "text",
            text: [ICONS.warningIcon],
            textfont: { color: COLORS.red, size: 25 },
          },
          x: [2],
          y: [metaData.voutp_clamped],
        });
      }
      if (metaData.error_voutn.status) {
        errorLines.push({
          otherOptions: {
            hoverlabel: errorLineHoverLabel,
            hovertemplate: `<b>${metaData.error_voutn.text}</b><extra></extra>`,
            mode: "text",
            text: [ICONS.warningIcon],
            textfont: { color: COLORS.red, size: 25 },
          },
          x: [2],
          y: [metaData.voutn_clamped],
        });
      }
      return [
        ...errorLines,
        // Center line
        {
          x: [1, 1],
          y: [metaData.avss - 0.5, metaData.avdd + 0.5],
          color: COLORS.black,
        },
        // AVDD
        {
          x: [0, 1.8],
          y: [metaData.avdd, metaData.avdd],
          color: COLORS.black,
          dash: "dot",
        },
        // AVSS
        {
          x: [0, 1.8],
          y: [metaData.avss, metaData.avss],
          color: COLORS.black,
          dash: "dot",
        },
        // AINP
        {
          x: [0.4, 0.6],
          y: [metaData.ainp, metaData.ainp],
          color: COLORS.darkBlue,
        },
        // AINN
        {
          x: [0.4, 0.6],
          y: [metaData.ainn, metaData.ainn],
          color: COLORS.maximumBlue,
        },
        // DIFF I/P
        {
          x: [0.5, 0.5],
          y: [metaData.ainp, metaData.ainn],
          color: COLORS.brilliantAzure,
          dash: "dot",
        },
        // VOUTP CLAMPED
        {
          x: [1.4, 1.6],
          y: [metaData.voutp_clamped, metaData.voutp_clamped],
          color: COLORS.darkBlue,
        },
        // VOUTN CLAMPED
        {
          x: [1.4, 1.6],
          y: [metaData.voutn_clamped, metaData.voutn_clamped],
          color: COLORS.maximumBlue,
        },
        // DIFF I/P
        {
          x: [1.5, 1.5],
          y: [metaData.voutp_clamped, metaData.voutn_clamped],
          color: COLORS.brilliantAzure,
          dash: "dot",
        },
        // + I/P to O/P
        {
          x: [0.61, 1.39],
          y: [metaData.ainp, metaData.voutp_clamped],
          color: COLORS.black,
          dash: "dot",
        },
        // - I/P to O/P
        {
          x: [0.61, 1.39],
          y: [metaData.ainn, metaData.voutn_clamped],
          color: COLORS.black,
          dash: "dot",
        },
        // + I/P Limit
        {
          x: [0, 1],
          y: [metaData.pga_input_pos_limit, metaData.pga_input_pos_limit],
          color: COLORS.red,
          width: 3,
        },
        // - I/P Limit
        {
          x: [0, 1],
          y: [metaData.pga_input_neg_limit, metaData.pga_input_neg_limit],
          color: COLORS.red,
          width: 3,
        },
        // VOUT MAX
        {
          x: [1, 1.8],
          y: [metaData.vout_max, metaData.vout_max],
          color: COLORS.red,
          width: 3,
        },
        // VOUT MIN
        {
          x: [1, 1.8],
          y: [metaData.vout_min, metaData.vout_min],
          color: COLORS.red,
          width: 3,
        },
      ];
    };
    /**
     * To get Y axis limits
     * @param lineInfoList
     * @returns Y axis limits
     */
    this.getGraphYAxisLimits = lineInfoList => {
      let yAxisValuesList = lineInfoList.reduce((acc, line) => {
        acc.push(...line.y);
        return acc;
      }, []);
      return {
        max: Math.max(...yAxisValuesList),
        min: Math.min(...yAxisValuesList),
      };
    };
    /**
     * To get value for CM range graph
     * @param lineInfoList
     * @param metaData
     * @param yAxisLimits
     * @returns CM range graph value object
     */
    this.getGraphValueObj = (lineInfoList, metaData, yAxisLimits) => {
      return {
        layout: getGraphLayoutObj(this.getGraphAnnotationsInfoList(yAxisLimits.max, metaData), [this.getGraphImageInfo(metaData.graph_image, metaData)], {
          showticklabels: false,
          showgrid: false,
        }, {
          title: {
            text: "<b>Voltage (V)</b>",
            font: {
              size: 12,
            },
          },
          zeroline: false,
        }),
        data: getGraphDataObj(lineInfoList.map(lineInfo => {
          return Object.assign(Object.assign({}, lineInfo), { hoverinfo: lineInfo.hoverinfo || "y" });
        })),
      };
    };
    /**
     * To get output info
     * @param outputInfo Output info object
     * @returns Output element
     */
    this.getOutputElement = (outputInfo, dataPath) => {
      if (outputInfo.outputType === "graph" && outputInfo.metaData) {
        const lineInfoList = this.getGraphLineInfoList(outputInfo.metaData);
        const yAxisLimits = this.getGraphYAxisLimits(lineInfoList);
        outputInfo = Object.assign(Object.assign({}, outputInfo), { limits: {
            /**
             * The warningIcon is shown at x = 2.
             *
             * So, after adding a step size of 0.2 with that, the xaxisMaxValue is configured as 2.2.
             */
            xaxisMax: 2.2,
            xaxisMin: 0,
            /**
             * To accommodate title annotations (PGA Input/Output),
             *
             * Step size of 1 is added with the maximum Y axis value.
             */
            yaxisMax: yAxisLimits.max + 1,
            yaxisMin: yAxisLimits.min,
          }, value: this.getGraphValueObj(lineInfoList, outputInfo.metaData, yAxisLimits) });
      }
      return (h("ads-output", { "selected-device": this.selectedDevice, "tool-name": "cm-range", key: getElementKey(outputInfo), outputInfo: outputInfo, dataPath: dataPath, onSetPathValue: ev => updateConfigData.call(this, ev), selectedPageIndex: this.selectedPageIndex }));
    };
    this.selectedDevice = undefined;
    this.selectedPageIndex = undefined;
    this.selectedToolName = undefined;
    this.config = undefined;
    this.selectedTabId = undefined;
    this.selectedOutputSubCategoryId = undefined;
  }
  // ---------- Life cycle methods ----------
  componentDidLoad() {
    if (this.config === undefined && this.selectedDevice !== undefined) {
      this.loadPageConfig();
    }
  }
  // ----------- Watch handlers -------------
  loadPageConfig() {
    loadAndUpdatePageConfig.call(this, this.selectedToolName, this.selectedDevice);
  }
  onSelectedTabChanged() {
    if (this.config != undefined) {
      updateCurrentTabWithMappingsFromOtherTabs.call(this);
      updateResultants.call(this, true);
    }
  }
  render() {
    return this.config != undefined && this.isComputedValuesInitialized
      ? [
        h("div", { class: "page-header" }, h("div", { class: "page-title" }, "Common Mode Range Tool"), h("ads-dropdown-menu", { name: "Related links", items: this.config.collaterals })),
        h("div", { class: "page-content" }, h("div", { class: "left-section", id: "left-section" }, h("div", { class: "section-title" }, this.config.label), h("div", { class: "section-tabs" }, h("ads-tabs", { tabNamesObj: getTabNamesObj(this.config.tabs), selectedTabId: this.selectedTabId, selectedPageIndex: this.selectedPageIndex, onUpdateSelectedTab: ev => updateSelectedTabId.call(this, ev), "hide-if-single-tab": true }), h("div", { class: "tab-content" }, this.getControlSectionGroups()))), h("div", { class: "right-section", id: "right-section" }, h("div", { class: "section-title" }, "Resultant Calculations"), h("div", { class: "section-outputs" }, this.selectedTabId != undefined && (h("ads-tabs", { tabNamesObj: getOutputSubCategoriesObj.call(this), selectedTabId: this.selectedOutputSubCategoryId, selectedPageIndex: this.selectedPageIndex, onUpdateSelectedTab: ev => updateSelectedOutputSubCategoryId.call(this, ev), "hide-if-single-tab": true })), h("div", { class: "tab-content" }, getOutputSection.call(this))))),
      ]
      : [];
  }
  get host() { return getElement(this); }
  static get watchers() { return {
    "selectedDevice": ["loadPageConfig"],
    "selectedTabId": ["onSelectedTabChanged"]
  }; }
};
AdsCmRange.style = adsCmRangeCss;

export { AdsCmRange as ads_cm_range };

//# sourceMappingURL=p-c6ba0e18.entry.js.map